'use strict'

const webpack = require('webpack')
const TerserPlugin = require('terser-webpack-plugin')

const { target } = require('cozy-scripts/config/webpack.vars')

module.exports = {
  mode: 'production',
  plugins: [
    // use a hash as chunk id to avoid id changes of not changing chunk
    new webpack.HashedModuleIdsPlugin(),
    new webpack.optimize.OccurrenceOrderPlugin(),
    new webpack.DefinePlugin({
      'process.env.NODE_ENV': JSON.stringify('production'), // to compile on production mode (redux)
      __IS_ALPHA__: false,
      __DEVELOPMENT__: false,
      __DEVTOOLS__: false,
      __STACK_ASSETS__: target !== 'mobile',
      __PIWIK_TRACKER_URL__: JSON.stringify('https://statweb.grandlyon.com/'),
      __PIWIK_SITEID__: 118,
      __SAU_LINK__: JSON.stringify('https://support.grandlyon.com/ecolyo/'),
      __SAU_IDEA_DIRECT_LINK__: JSON.stringify(
        'https://demarches-support.grandlyon.com/retour-ecolyo/ecolyo-une-idee/'
      ),
      __SENTRY_DSN__: JSON.stringify(
        'https://c868f6010f3f431d95be8f70d7f37666@grandlyon.errors.cozycloud.cc/6'
      ),
    }),
  ],
  optimization: {
    minimizer: [
      new TerserPlugin({
        parallel: true,
        //To fix a SAfari 10 bug : https://github.com/zeit/next.js/issues/5630
        terserOptions: {
          safari10: true,
        },
      }),
    ],
  },
}
