import React from 'react'
import { withStyles } from '@material-ui/core/styles'
import IconButton, { IconButtonProps } from '@material-ui/core/IconButton'
import StyledIconProps from 'components/CommonKit/Icon/StyledIcon'

const IconButtonBase = withStyles({
  root: {
    outline: 'none !important',
    borderRadius: '4px',
    width: '100%',
    padding: 'unset',
  },
  label: {
    display: 'flex',
    flexDirection: 'column',
  },
})(IconButton) as React.FC<IconButtonProps>

const SelectedIconButtonBase = withStyles({
  root: {
    border: '1px solid var(--multiColor)',
    background: 'var(--greyLinearGradientBackground)',
    boxShadow: '0px 4px 16px rgba(0, 0, 0, 0.55)',
  },
})(IconButtonBase) as React.FC<IconButtonProps>

const UnselectedIconButtonBase = withStyles({
  root: {
    border: '1px solid var(--greyDark)',
  },
})(IconButtonBase) as React.FC<IconButtonProps>

interface StyledIconBorderedButtonProps extends IconButtonProps {
  icon: string
  sized?: number
  selected?: boolean
  children?: React.ReactNode
}

const StyledIconBorderedButton: React.FC<StyledIconBorderedButtonProps> = ({
  icon,
  sized = 16,
  selected = false,
  children = null,
  ...props
}: StyledIconBorderedButtonProps) => {
  return (
    <>
      {selected ? (
        <SelectedIconButtonBase {...props}>
          <StyledIconProps icon={icon} size={sized} />
          {children}
        </SelectedIconButtonBase>
      ) : (
        <UnselectedIconButtonBase {...props}>
          <StyledIconProps icon={icon} size={sized} />
          {children}
        </UnselectedIconButtonBase>
      )}
    </>
  )
}

export default StyledIconBorderedButton
