import React, { useCallback, useState } from 'react'
import './dataloadConsumptionVisualizer.scss'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
import { Dataload } from 'models'
import { FluidType } from 'enum/fluid.enum'
import EstimatedConsumptionModal from './EstimatedConsumptionModal'
import DataloadNoValue from './DataloadNoValue'
import { DataloadSectionType, DataloadState } from 'enum/dataload.enum'
import DataloadSection from './DataloadSection'

interface DataloadConsumptionVisualizerProps {
  fluidType: FluidType
  dataload: Dataload
  compareDataload: Dataload | null
  showCompare: boolean
  setActive: React.Dispatch<React.SetStateAction<boolean>>
}
const DataloadConsumptionVisualizer = ({
  fluidType,
  dataload,
  compareDataload,
  showCompare,
  setActive,
}: DataloadConsumptionVisualizerProps) => {
  const { loading } = useSelector((state: AppStore) => state.ecolyo.chart)
  const [openEstimationModal, setOpenEstimationModal] = useState<boolean>(false)

  const toggleEstimationModal = useCallback(() => {
    setOpenEstimationModal(prev => !prev)
  }, [])

  if (loading || !dataload) {
    return <div className="dataloadvisualizer-root" />
  }

  if (
    dataload.state !== DataloadState.VALID &&
    dataload.state !== DataloadState.AGGREGATED_VALID &&
    dataload.state !== DataloadState.AGGREGATED_WITH_EMPTY &&
    dataload.state !== DataloadState.AGGREGATED_WITH_HOLE_OR_MISSING &&
    dataload.state !== DataloadState.AGGREGATED_WITH_COMING
  ) {
    return (
      <div className="dataloadvisualizer-root">
        <DataloadNoValue
          dataload={dataload}
          setActive={setActive}
          fluidType={fluidType}
        />
      </div>
    )
  }

  return (
    <div className="dataloadvisualizer-root">
      <div className="dataloadvisualizer-content">
        {showCompare && compareDataload ? (
          <>
            <DataloadSection
              dataload={compareDataload}
              fluidType={fluidType}
              dataloadSectionType={DataloadSectionType.LEFT}
              toggleEstimationModal={toggleEstimationModal}
            />
            <DataloadSection
              dataload={dataload}
              fluidType={fluidType}
              dataloadSectionType={DataloadSectionType.RIGHT}
              toggleEstimationModal={toggleEstimationModal}
            />
          </>
        ) : (
          <DataloadSection
            dataload={dataload}
            fluidType={fluidType}
            dataloadSectionType={DataloadSectionType.NO_COMPARE}
            toggleEstimationModal={toggleEstimationModal}
          />
        )}
      </div>
      <EstimatedConsumptionModal
        open={openEstimationModal}
        handleCloseClick={toggleEstimationModal}
      />
    </div>
  )
}

export default DataloadConsumptionVisualizer
