import Button from '@material-ui/core/Button'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import DuelUnlocked from 'components/Duel/DuelUnlocked'
import { FluidType } from 'enum/fluid.enum'
import { UserChallengeUpdateFlag } from 'enum/userChallenge.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { formatNumberValues } from 'utils/utils'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockImportIconById = jest.fn()
const mockFormatNumberValues = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconById: jest.fn(() => {
      return mockImportIconById
    }),
    formatNumberValues: jest.fn(() => {
      return mockFormatNumberValues
    }),
  }
})
const mockUserChallengeUpdateFlag = jest.fn()
const mockGetUserChallengeDataload = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockUserChallengeUpdateFlag,
      getUserChallengeDataload: mockGetUserChallengeDataload,
    }
  })
})

const mockStore = configureStore([])

describe('DuelUnlocked component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const average: string = formatNumberValues(
      userChallengeData[1].duel.threshold
    ).toString()
    const description: string =
      '"' +
      userChallengeData[1].duel.description.replace('#CONSUMPTION', average) +
      '"'
    const wrapper = mount(
      <Provider store={store}>
        <DuelUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('.duel-title').text()).toEqual(
      userChallengeData[1].duel.title
    )
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    expect(wrapper.find('.duel-description').text()).toEqual(description)
    expect(wrapper.find('.duel-average-info').exists()).toBeTruthy()
    expect(wrapper.find('.button-start').exists()).toBeTruthy()
  })

  it('should update userChallenge when launching duel with configured fluid', () => {
    const updateGlobalStoreData = {
      ...globalStateData,
      fluidTypes: [FluidType.ELECTRICITY],
    }
    const store = mockStore({
      ecolyo: {
        global: updateGlobalStoreData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DuelUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.button-start').find(Button).simulate('click')
    expect(mockUserChallengeUpdateFlag).toHaveBeenCalledWith(
      userChallengeData[0],
      UserChallengeUpdateFlag.DUEL_START
    )
  })
})
