import Content from 'components/Content/Content'
import DuelError from 'components/Duel/DuelError'
import DuelUnlocked from 'components/Duel/DuelUnlocked'
import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import { UserChallengeState } from 'enum/userChallenge.enum'
import { UserDuelState } from 'enum/userDuel.enum'
import { UserChallenge } from 'models'
import React, { useCallback, useState } from 'react'
import { useSelector } from 'react-redux'
import { useLocation, useNavigate } from 'react-router-dom'
import { AppStore } from 'store'
import DuelEmptyValueModal from './DuelEmptyValueModal'
import DuelOngoing from './DuelOngoing'

const DuelView: React.FC = () => {
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const { userChallengeList } = useSelector(
    (state: AppStore) => state.ecolyo.challenge
  )
  const id = new URLSearchParams(useLocation().search).get('id')
  const challengeToDisplay: UserChallenge | undefined = userChallengeList.find(
    challenge => challenge.id === id
  )

  const navigate = useNavigate()
  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])
  const goBackToChallenge = () => {
    navigate('/challenges')
  }
  const renderDuel = (challenge: UserChallenge) => {
    switch (challenge.duel.state) {
      case UserDuelState.UNLOCKED:
        return <DuelUnlocked userChallenge={challenge} />
      case UserDuelState.ONGOING:
        return <DuelOngoing userChallenge={challenge} />
      case UserDuelState.DONE:
        return <DuelOngoing userChallenge={challenge} isFinished={true} />
      case UserDuelState.NO_REF_PERIOD_VALID:
        return (
          <DuelEmptyValueModal
            open={true}
            handleCloseClick={goBackToChallenge}
          />
        )
      default:
        return <DuelError />
    }
  }

  return (
    <>
      <CozyBar titleKey={'common.title_duel'} displayBackArrow={true} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'common.title_duel'}
        displayBackArrow={true}
      />
      <Content height={headerHeight}>
        <div>
          {challengeToDisplay &&
          (challengeToDisplay.state === UserChallengeState.DUEL ||
            challengeToDisplay.state === UserChallengeState.DONE) ? (
            renderDuel(challengeToDisplay)
          ) : (
            <DuelError />
          )}
        </div>
      </Content>
    </>
  )
}

export default DuelView
