import Button from '@material-ui/core/Button'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profileData.mock'
import EcogestureEmptyList from './EcogestureEmptyList'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))
const mockStore = configureStore([])
const mockChangeTab = jest.fn()
describe('EcogestureEmptyList component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureEmptyList
          setTab={mockChangeTab}
          isObjective={true}
          isSelectionDone={false}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should return to all ecogestures', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureEmptyList
          setTab={mockChangeTab}
          isObjective={false}
          isSelectionDone={true}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockChangeTab).toHaveBeenCalledTimes(1)
  })
  it('should launch ecogesture form', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureEmptyList
          setTab={mockChangeTab}
          isObjective={false}
          isSelectionDone={false}
        />
      </Provider>
    )
    wrapper.find(Button).at(1).simulate('click')
    expect(mockedNavigate).toHaveBeenCalledWith('/ecogesture-form')
  })
  it('should render doing text with empty list on completed selection', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureEmptyList
          setTab={mockChangeTab}
          isObjective={false}
          isSelectionDone={true}
        />
      </Provider>
    )

    expect(wrapper.find('.text').first().text()).toBe(
      'ecogesture.emptyList.doing1_done'
    )
  })
  it('should render objective text with empty list on completed selection', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureEmptyList
          setTab={mockChangeTab}
          isObjective={true}
          isSelectionDone={true}
        />
      </Provider>
    )

    expect(wrapper.find('.text').first().text()).toBe(
      'ecogesture.emptyList.obj1_done'
    )
  })
})
