import React, { useCallback, useEffect, useState } from 'react'
import 'components/ProfileType/profileTypeForm.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import classNames from 'classnames'
import FormNavigation from 'components/FormGlobal/FormNavigation'
import { EcogestureStepForm } from 'enum/ecogestureForm.enum'
import {
  ProfileEcogesture,
  ProfileEcogestureAnswer,
  ProfileEcogestureAnswerChoices,
} from 'models/profileEcogesture.model'
import './ecogestureFormSingleChoice.scss'
import { useSelector } from 'react-redux'
import { AppStore } from 'store'
interface EcogestureFormSingleChoiceProps {
  step: EcogestureStepForm
  viewedStep: EcogestureStepForm
  profileEcogesture: ProfileEcogesture
  answerType: ProfileEcogestureAnswer
  setNextStep: Function
  setPrevioustStep: Function
}

const EcogestureFormSingleChoice: React.FC<EcogestureFormSingleChoiceProps> = ({
  step,
  viewedStep,
  profileEcogesture,
  answerType,
  setNextStep,
  setPrevioustStep,
}: EcogestureFormSingleChoiceProps) => {
  const { t } = useI18n()
  const { isProfileEcogestureCompleted } = useSelector(
    (state: AppStore) => state.ecolyo.profile
  )
  const [answer, setAnswer] = useState<ProfileEcogestureAnswerChoices>(
    isProfileEcogestureCompleted ? profileEcogesture[answerType.attribute] : ''
  )

  const handlePrevious = useCallback(() => {
    setPrevioustStep(profileEcogesture)
  }, [profileEcogesture, setPrevioustStep])

  const handleAnswer = useCallback((value: ProfileEcogestureAnswerChoices) => {
    setAnswer(value)
  }, [])

  const handleNext = useCallback(() => {
    profileEcogesture[answerType.attribute] = answer
    setNextStep(profileEcogesture)
  }, [profileEcogesture, setNextStep, answer, answerType.attribute])

  useEffect(() => {
    if (step < viewedStep) {
      setAnswer(profileEcogesture[answerType.attribute])
    }
  }, [step, viewedStep, profileEcogesture, answerType])

  return (
    <div className="ecogesture-profile-container">
      <div className={'profile-form-container ecogesture-form-single'}>
        <div className={'profile-question-label'}>
          {t(
            `ecogesture_form.${EcogestureStepForm[step].toLowerCase()}.question`
          )}
        </div>
        {answerType.choices.map(
          (value: ProfileEcogestureAnswerChoices, index: number) => {
            return value || value === 0 ? (
              <label
                key={index}
                className={classNames({
                  ['radio_short']: answerType.choices.length < 5,
                  ['radio_long']: answerType.choices.length > 4,
                  ['answer-checked']: answer === value,
                })}
              >
                <input
                  type={'radio'}
                  value={value}
                  name={value.toString()}
                  onChange={() => handleAnswer(value)}
                  checked={answer === value ? true : false}
                  className={answer === value ? 'checked-input' : ''}
                />
                {t(
                  `ecogesture_form.${EcogestureStepForm[
                    step
                  ].toLowerCase()}.${value}`
                )}
              </label>
            ) : null
          }
        )}
      </div>
      <FormNavigation
        step={step}
        handlePrevious={handlePrevious}
        handleNext={handleNext}
        disableNextButton={answer === ''}
        isEcogesture={true}
      />
    </div>
  )
}

export default EcogestureFormSingleChoice
