/* eslint-disable react/display-name */
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import React from 'react'
import { Provider } from 'react-redux'
import mockClient from '../../../tests/__mocks__/client'
import { ecogesturesData } from '../../../tests/__mocks__/ecogesturesData.mock'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureSelection from './EcogestureSelection'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('cozy-client', () => {
  return {
    useClient: jest.fn(() => {
      return mockClient
    }),
  }
})
const mockHistoryGoBack = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => {
    return {
      search: '',
    }
  },
  useNavigate: () => ({
    push: mockHistoryGoBack,
  }),
}))
const mockGetEcogestureListByProfile = jest.fn()
jest.mock('services/ecogesture.service', () => {
  return jest.fn(() => {
    return {
      getEcogestureListByProfile: mockGetEcogestureListByProfile,
    }
  })
})

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionModal',
  () => 'mock-ecogestureselectionmodal'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionDetail',
  () => 'mock-ecogestureselectiondetail'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionRestart',
  () => 'mock-ecogestureselectionrestart'
)
jest.mock(
  'components/EcogestureSelection/EcogestureSelectionEnd',
  () => 'mock-ecogestureselectionend'
)

describe('EcogestureSelection component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    mockGetEcogestureListByProfile.mockClear()
  })

  it('should be rendered correctly', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([ecogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelection />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should render with the EcogestureSelectionModal', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([ecogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelection />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureselectionmodal').exists()).toBeTruthy()
  })
  it('should render with the EcogestureSelectionDetail', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([ecogesturesData[0]])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelection />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureselectiondetail').exists()).toBeTruthy()
  })
  it('should render with the EcogestureSelectionEnd', async () => {
    mockGetEcogestureListByProfile.mockResolvedValue([])
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureSelection />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('mock-ecogestureselectionend').exists()).toBeTruthy()
  })
})
