import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'

import { Button } from '@material-ui/core'
import { FluidType } from 'enum/fluid.enum'
import { KonnectorError } from 'enum/konnectorError.enum'
import toJson from 'enzyme-to-json'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import KonnectorModal from './KonnectorModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

describe('KonnectorModal component', () => {
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    jest.clearAllMocks()
  })
  const mockHandleCloseClick = jest.fn()
  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={false}
          state={null}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should be with updating text', () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={true}
          state={null}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(wrapper.find('.kmodal-waiting-text').exists()).toBeTruthy()
  })
  it('should be correctly closed', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={false}
          state={'errored'}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    wrapper.find(Button).simulate('click')
    expect(mockHandleCloseClick).toHaveBeenCalled()
  })
  it('should render login error', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={false}
          state={'error'}
          error={KonnectorError.LOGIN_FAILED}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(wrapper.find('.kce-picto-txt').exists()).toBeTruthy()
  })
  it('should render unknown error', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={false}
          state={'error'}
          error={null}
          fluidType={FluidType.ELECTRICITY}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    expect(wrapper.find('.err-data-2').exists()).toBeTruthy()
  })
  it('should render update error', async () => {
    const wrapper = mount(
      <Provider store={store}>
        <KonnectorModal
          open={true}
          isUpdating={true}
          state={null}
          error={null}
          fluidType={FluidType.WATER}
          handleCloseClick={mockHandleCloseClick}
          isLogging={false}
          account={null}
          handleAccountDeletion={jest.fn()}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.waiting-text').exists()).toBeTruthy()
  })
})
