import profileIcon from 'assets/icons/ico/profile.svg'
import StyledCard from 'components/CommonKit/Card/StyledCard'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import ProfileTypeOptions from 'components/Options/ProfileTypeOptions/ProfileTypeOptions'
import {
  HousingType,
  IndividualInsulationWork,
  IndividualOrCollective,
  ThreeChoicesAnswer,
} from 'enum/profileType.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { profileData } from '../../../../tests/__mocks__/profileData.mock'
import { mockProfileType } from '../../../../tests/__mocks__/profileType.mock'
import { mockInitialChallengeState } from '../../../../tests/__mocks__/store'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

const mockStore = configureStore([])

describe('ProfileTypeOptions component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        profileType: mockProfileType,
        challenge: mockInitialChallengeState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find(StyledCard).exists()).toBeTruthy()
    expect(wrapper.find(StyledIcon).exists()).toBeTruthy()
    expect(wrapper.find(profileIcon)).toBeTruthy()
    wrapper.find('.profile-link').first().simulate('click')
  })
  it('should be rendered when user complete profile type form', () => {
    const profileTypeCompleted = { ...profileData }
    const profileTypeData = { ...mockProfileType }
    profileTypeCompleted.isProfileTypeCompleted = true
    const store = mockStore({
      ecolyo: {
        profile: profileTypeCompleted,
        profileType: profileTypeData,
        challenge: mockInitialChallengeState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.profile-container').exists()).toBeTruthy()
  })
  it('should be rendered when housing_type = appartment', () => {
    const profileTypeCompleted = { ...profileData }
    const profileTypeData = { ...mockProfileType }
    profileTypeCompleted.isProfileTypeCompleted = true
    profileTypeData.housingType = HousingType.APPARTMENT
    const store = mockStore({
      ecolyo: {
        profile: profileTypeCompleted,
        profileType: profileTypeData,
        challenge: mockInitialChallengeState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.floor').exists()).toBeTruthy()
  })
  it('should display heating with equipments', () => {
    const profileTypeCompleted = {
      ...profileData,
    }
    const profileTypeData = { ...mockProfileType }

    profileTypeData.heating = IndividualOrCollective.INDIVIDUAL
    profileTypeCompleted.isProfileTypeCompleted = true
    profileTypeData.housingType = HousingType.APPARTMENT
    profileTypeData.hasInstalledVentilation = ThreeChoicesAnswer.YES
    profileTypeData.hasReplacedHeater = ThreeChoicesAnswer.YES
    const store = mockStore({
      ecolyo: {
        profile: profileTypeCompleted,
        profileType: profileTypeData,
        challenge: mockInitialChallengeState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.equipments').exists()).toBeTruthy()
  })
  it('should display insulation work', () => {
    const profileTypeCompleted = {
      ...profileData,
    }
    const profileTypeData = { ...mockProfileType }

    profileTypeCompleted.isProfileTypeCompleted = true
    profileTypeData.housingType = HousingType.APPARTMENT
    profileTypeData.individualInsulationWork = [
      IndividualInsulationWork.ROOF_INSULATION,
      IndividualInsulationWork.WINDOW_REPLACEMENT,
    ]
    const store = mockStore({
      ecolyo: {
        profile: profileTypeCompleted,
        profileType: profileTypeData,
        challenge: mockInitialChallengeState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ProfileTypeOptions />
      </Provider>
    )
    expect(wrapper.find('.insulation').exists()).toBeTruthy()
  })
})
