import { Reducer } from 'redux'
import {
  SET_USER_CHALLENGE_LIST,
  UPDATE_USER_CHALLENGE_LIST,
  UNLOCK_NEXT_USER_CHALLENGE,
  SET_CHALLENGE_CONSUMPTION,
  ChallengeActionTypes,
} from './challenge.actions'
import { ChallengeState } from 'models'
import { UserChallengeState } from 'enum/userChallenge.enum'

const initialState: ChallengeState = {
  userChallengeList: [],
  currentChallenge: null,
  currentDataload: [],
}

export const challengeReducer: Reducer<ChallengeState> = (
  state = initialState,
  action: ChallengeActionTypes
): ChallengeState => {
  switch (action.type) {
    case SET_USER_CHALLENGE_LIST:
      if (action.payload !== undefined) {
        const filteredCurrentChallenge = action.payload.filter(
          challenge =>
            challenge.state === UserChallengeState.ONGOING ||
            challenge.state === UserChallengeState.DUEL
        )
        const currentChallenge = filteredCurrentChallenge[0]
          ? filteredCurrentChallenge[0]
          : null
        return {
          ...state,
          userChallengeList: action.payload,
          currentChallenge: currentChallenge,
        }
      } else {
        return state
      }
    case UPDATE_USER_CHALLENGE_LIST:
      if (action.payload !== undefined) {
        const id = action.payload.id
        const currentChallenge =
          action.payload.state === UserChallengeState.ONGOING ||
          action.payload.state === UserChallengeState.DUEL
            ? action.payload
            : null
        const updatedList = [...state.userChallengeList]
        const findIndex = updatedList.findIndex(
          challenge => challenge.id === id
        )
        updatedList[findIndex] = action.payload
        return {
          ...state,
          userChallengeList: updatedList,
          currentChallenge: currentChallenge
            ? currentChallenge
            : state.currentChallenge,
        }
      } else {
        return state
      }
    case UNLOCK_NEXT_USER_CHALLENGE:
      if (action.payload !== undefined) {
        const id = action.payload.id
        const updatedList = [...state.userChallengeList]
        const findIndex = updatedList.findIndex(
          challenge => challenge.id === id
        )
        updatedList[findIndex] = action.payload
        if (typeof updatedList[findIndex + 1] !== 'undefined') {
          updatedList[findIndex + 1] = {
            ...updatedList[findIndex + 1],
            state: UserChallengeState.UNLOCKED,
          }
        }
        return {
          ...state,
          userChallengeList: updatedList,
          currentChallenge: null,
        }
      } else {
        return state
      }
    case SET_CHALLENGE_CONSUMPTION:
      if (action.payload !== undefined) {
        const id = action.payload.userChallenge.id
        const updatedList = [...state.userChallengeList]
        const findIndex = updatedList.findIndex(
          challenge => challenge.id === id
        )
        updatedList[findIndex] = action.payload.userChallenge
        return {
          ...state,
          userChallengeList: updatedList,
          currentChallenge:
            state.currentChallenge &&
            state.currentChallenge.id === action.payload.userChallenge.id
              ? action.payload.userChallenge
              : state.currentChallenge,
          currentDataload: action.payload.currentDataload,
        }
      } else {
        return state
      }
    default:
      return state
  }
}
