import { FluidType } from 'enum/fluid.enum'
import { ScreenType } from 'enum/screen.enum'
import { FluidConnection, FluidStatus, TermsStatus } from 'models'
import { CustomPopup } from 'models/customPopup.model'
import { Notes } from 'models/releaseNotes.model'
import { SgeStore } from 'models/sgeStore.model'

export const CHANGE_SCREEN_TYPE = 'CHANGE_SCREEN_TYPE'
export const SHOW_RELEASE_NOTES = 'SHOW_RELEASE_NOTES'
export const TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION =
  'TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION'
export const TOGGLE_CHALLENGE_ACTION_NOTIFICATION =
  'TOGGLE_CHALLENGE_ACTION_NOTIFICATION'
export const TOGGLE_CHALLENGE_DUEL_NOTIFICATION =
  'TOGGLE_CHALLENGE_DUEL_NOTIFICATION'
export const TOGGLE_ANALYSIS_NOTIFICATION = 'TOGGLE_ANALYSIS_NOTIFICATION'
export const SET_FLUID_STATUS = 'SET_FLUID_STATUS'
export const UPDATE_FLUID_CONNECTION = 'UPDATE_FLUID_CONNECTION'
export const UPDATE_TERMS_VALIDATION = 'UPDATE_TERMS_VALIDATION'
export const SET_PARTNERS_ISSUE = 'SET_PARTNERS_ISSUE'
export const SET_CUSTOM_POPUP = 'SET_CUSTOM_POPUP'
export const SET_SHOULD_REFRESH_CONSENT = 'SET_SHOULD_REFRESH_CONSENT'
export const UPDATE_SGE_CONNECT = 'UPDATE_SGE_CONNECT'
interface ChangeScreenType {
  type: typeof CHANGE_SCREEN_TYPE
  payload?: ScreenType
}

interface ToogleChallengeExplorationNotification {
  type: typeof TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION
  payload?: boolean
}

interface ToogleChallengeActionNotification {
  type: typeof TOGGLE_CHALLENGE_ACTION_NOTIFICATION
  payload?: boolean
}

interface ToogleChallengeDuelNotification {
  type: typeof TOGGLE_CHALLENGE_DUEL_NOTIFICATION
  payload?: boolean
}

interface ToogleAnalysisNotification {
  type: typeof TOGGLE_ANALYSIS_NOTIFICATION
  payload?: boolean
}

interface SetFluidStatus {
  type: typeof SET_FLUID_STATUS
  payload?: FluidStatus[]
}

interface UpdatedFluidConnection {
  type: typeof UPDATE_FLUID_CONNECTION
  payload?: { fluidType: FluidType; fluidConnection: FluidConnection }
}

interface UpdateTermValidation {
  type: typeof UPDATE_TERMS_VALIDATION
  payload?: TermsStatus
}

interface ShowReleaseNotes {
  type: typeof SHOW_RELEASE_NOTES
  payload?: { show: boolean; notes: Notes[]; redirectLink?: string }
}

interface SetPartnersIssue {
  type: typeof SET_PARTNERS_ISSUE
  payload?: {
    enedis: boolean
    egl: boolean
    grdf: boolean
  }
}

interface SetCustomPopup {
  type: typeof SET_CUSTOM_POPUP
  payload: CustomPopup
}

interface SetShouldRefreshConsent {
  type: typeof SET_SHOULD_REFRESH_CONSENT
  payload?: boolean
}
export interface UpdateSGEConnect {
  type: typeof UPDATE_SGE_CONNECT
  payload?: SgeStore
}

export type GlobalActionTypes =
  | ChangeScreenType
  | ToogleChallengeExplorationNotification
  | ToogleChallengeActionNotification
  | ToogleChallengeDuelNotification
  | ToogleAnalysisNotification
  | SetFluidStatus
  | UpdatedFluidConnection
  | UpdateTermValidation
  | ShowReleaseNotes
  | SetPartnersIssue
  | SetCustomPopup
  | SetShouldRefreshConsent
  | UpdateSGEConnect

export function changeScreenType(screenType: ScreenType): GlobalActionTypes {
  return {
    type: CHANGE_SCREEN_TYPE,
    payload: screenType,
  }
}

export function showReleaseNotes(
  show: boolean,
  notes: Notes[],
  redirectLink?: string
): GlobalActionTypes {
  return {
    type: SHOW_RELEASE_NOTES,
    payload: { show, notes, redirectLink },
  }
}

export function toggleChallengeExplorationNotification(
  notif: boolean
): GlobalActionTypes {
  return {
    type: TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
    payload: notif,
  }
}

export function toggleChallengeActionNotification(
  notif: boolean
): GlobalActionTypes {
  return {
    type: TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
    payload: notif,
  }
}

export function toggleChallengeDuelNotification(
  notif: boolean
): GlobalActionTypes {
  return {
    type: TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
    payload: notif,
  }
}

export function toggleAnalysisNotification(notif: boolean): GlobalActionTypes {
  return {
    type: TOGGLE_ANALYSIS_NOTIFICATION,
    payload: notif,
  }
}

export function setFluidStatus(fluidStatus: FluidStatus[]): GlobalActionTypes {
  return {
    type: SET_FLUID_STATUS,
    payload: fluidStatus,
  }
}
export function updatedFluidConnection(
  fluidType: FluidType,
  fluidConnection: FluidConnection
): GlobalActionTypes {
  return {
    type: UPDATE_FLUID_CONNECTION,
    payload: { fluidType, fluidConnection },
  }
}

export function updateTermValidation(
  termsStatus: TermsStatus
): GlobalActionTypes {
  return {
    type: UPDATE_TERMS_VALIDATION,
    payload: termsStatus,
  }
}

export function setPartnersIssue(openPartnersIssueModal: {
  enedis: boolean
  egl: boolean
  grdf: boolean
}): GlobalActionTypes {
  return {
    type: SET_PARTNERS_ISSUE,
    payload: openPartnersIssueModal,
  }
}

export function setCustomPopup(
  customPopupModal: CustomPopup
): GlobalActionTypes {
  return {
    type: SET_CUSTOM_POPUP,
    payload: customPopupModal,
  }
}

export function setShouldRefreshConsent(
  shouldRefreshConsent: boolean
): GlobalActionTypes {
  return {
    type: SET_SHOULD_REFRESH_CONSENT,
    payload: shouldRefreshConsent,
  }
}

export function updateSgeStore(sgeStore: SgeStore): GlobalActionTypes {
  return {
    type: UPDATE_SGE_CONNECT,
    payload: sgeStore,
  }
}
