import { FluidState, FluidType } from 'enum/fluid.enum'
import { FluidSlugType } from 'enum/fluidSlug.enum'
import { ScreenType } from 'enum/screen.enum'
import { FluidStatus, GlobalState } from 'models'
import { Reducer } from 'redux'
import {
  CHANGE_SCREEN_TYPE,
  GlobalActionTypes,
  SET_CUSTOM_POPUP,
  SET_FLUID_STATUS,
  SET_PARTNERS_ISSUE,
  SET_SHOULD_REFRESH_CONSENT,
  SHOW_RELEASE_NOTES,
  TOGGLE_ANALYSIS_NOTIFICATION,
  TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
  TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
  TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
  UPDATE_FLUID_CONNECTION,
  UPDATE_SGE_CONNECT,
  UPDATE_TERMS_VALIDATION,
} from 'store/global/global.actions'

const initialState: GlobalState = {
  screenType: ScreenType.MOBILE,
  releaseNotes: {
    show: false,
    notes: [
      {
        title: '',
        description: '',
      },
    ],
  },
  challengeExplorationNotification: false,
  challengeActionNotification: false,
  challengeDuelNotification: false,
  analysisNotification: false,
  termsStatus: {
    accepted: false,
    versionType: 'init',
  },
  fluidStatus: [
    {
      fluidType: FluidType.ELECTRICITY,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.ELECTRICITY,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.WATER,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.WATER,
          siteLink: '',
          activation: '',
        },
      },
    },
    {
      fluidType: FluidType.GAS,
      status: FluidState.KONNECTOR_NOT_FOUND,
      maintenance: false,
      firstDataDate: null,
      lastDataDate: null,
      connection: {
        shouldLaunchKonnector: false,
        isUpdating: false,
        konnector: null,
        account: null,
        trigger: null,
        triggerState: null,
        konnectorConfig: {
          name: '',
          oauth: false,
          slug: FluidSlugType.GAS,
          siteLink: '',
          activation: '',
        },
      },
    },
  ],
  fluidTypes: [],
  customPopupModal: {
    popupEnabled: false,
    title: '',
    description: '',
    endDate: '',
  },
  openPartnersIssueModal: {
    enedis: false,
    egl: false,
    grdf: false,
  },
  shouldRefreshConsent: false,
  sgeConnect: {
    currentStep: 0,
    firstName: '',
    lastName: '',
    pdl: null,
    address: '',
    zipCode: null,
    city: '',
    dataConsent: false,
    pdlConfirm: false,
    shouldLaunchAccount: false,
  },
}

const getFluidTypesFromStatus = (fluidStatus: FluidStatus[]): FluidType[] => {
  const fluidTypes: FluidType[] = []
  fluidStatus.forEach(fluid => {
    if (
      (fluid.status !== FluidState.KONNECTOR_NOT_FOUND &&
        fluid.status !== FluidState.NOT_CONNECTED &&
        fluid.status !== FluidState.ERROR_LOGIN_FAILED) ||
      // Handle Login Error case for oauth konnectors
      (fluid.status === FluidState.ERROR_LOGIN_FAILED &&
        fluid.fluidType !== FluidType.WATER)
    ) {
      fluidTypes.push(fluid.fluidType)
    }
  })
  return fluidTypes.sort()
}

export const globalReducer: Reducer<GlobalState> = (
  state = initialState,
  action: GlobalActionTypes
): GlobalState => {
  switch (action.type) {
    case CHANGE_SCREEN_TYPE:
      return action.payload != undefined
        ? {
            ...state,
            screenType: action.payload,
          }
        : state
    case TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION:
      return action.payload != undefined
        ? {
            ...state,
            challengeExplorationNotification: action.payload,
          }
        : state
    case TOGGLE_CHALLENGE_ACTION_NOTIFICATION:
      return action.payload != undefined
        ? {
            ...state,
            challengeActionNotification: action.payload,
          }
        : state
    case TOGGLE_CHALLENGE_DUEL_NOTIFICATION:
      return action.payload != undefined
        ? {
            ...state,
            challengeDuelNotification: action.payload,
          }
        : state
    case TOGGLE_ANALYSIS_NOTIFICATION:
      return action.payload != undefined
        ? {
            ...state,
            analysisNotification: action.payload,
          }
        : state
    case SET_FLUID_STATUS:
      return action.payload != undefined
        ? {
            ...state,
            fluidStatus: action.payload,
            fluidTypes: getFluidTypesFromStatus(action.payload),
          }
        : state
    case UPDATE_TERMS_VALIDATION:
      return action.payload != undefined
        ? {
            ...state,
            termsStatus: action.payload,
          }
        : state
    case SHOW_RELEASE_NOTES:
      return action.payload != undefined
        ? {
            ...state,
            releaseNotes: action.payload,
          }
        : state
    case SET_PARTNERS_ISSUE:
      return action.payload != undefined
        ? {
            ...state,
            openPartnersIssueModal: action.payload,
          }
        : state
    case SET_CUSTOM_POPUP:
      return {
        ...state,
        customPopupModal: action.payload,
      }
    case SET_SHOULD_REFRESH_CONSENT:
      return action.payload != undefined
        ? {
            ...state,
            shouldRefreshConsent: action.payload,
          }
        : state
    case UPDATE_FLUID_CONNECTION:
      if (action.payload !== undefined) {
        const updatedFluidStatus = [...state.fluidStatus]
        const fluidType: FluidType = action.payload.fluidType
        const findIndex = state.fluidStatus.findIndex(
          fluid => fluid.fluidType === fluidType
        )
        updatedFluidStatus[findIndex].connection =
          action.payload.fluidConnection
        return {
          ...state,
          fluidStatus: updatedFluidStatus,
        }
      } else {
        return state
      }
    case UPDATE_SGE_CONNECT:
      if (action.payload != undefined)
        return {
          ...state,
          sgeConnect: action.payload,
        }
      return state
    default:
      return state
  }
}
